# Flask-Statics-Helper

Provides Bootstrap3 and other static resources in a modular fashion.

## Supported Platforms

* OSX and Linux.
* Python 2.7
* [Flask](http://flask.pocoo.org/) 0.10.1

## Install

```bash
pip install Flask-Statics-Helper
```

## Configuration

The following config settings are searched for in the Flask application's configuration dictionary:
* `STATICS_MINIFY` -- Have minified resources selected instead of uncompressed resources.
* `STATICS_ENABLE_RESOURCE_ANGULARJS` -- include resource in all templates.
* `STATICS_ENABLE_RESOURCE_BOOTSTRAP` -- include resource in all templates.
* `STATICS_ENABLE_RESOURCE_BOOTSTRAP_EDITABLE` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_BOOTSTRAP_GROWL` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_BOOTSTRAP_TYPEAHEAD` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_CSSHAKE` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_D3` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_DATATABLES` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_FONT_AWESOME` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_JQUERY` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_WHHG_FONT` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_ANIMATE` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_COOKIES` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_CSP` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_LOADER` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_MESSAGES` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_MOCKS` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_RESOURCE` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_ROUTE` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_SANITIZE` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_SCENARIO` --  include resource in all templates.
* `STATICS_ENABLE_RESOURCE_ANGULARJS_TOUCH` --  include resource in all templates.
